@@ -139,6 +139,7 @@ static void free_sublinkage(Sublinkage *s)
 
 static void replace_link_name(Link *l, const char *s)
 {
+	/* XXX can get some perf improvement by avoiding strlen! */
 	char * t;
 	exfree((char *) l->name, sizeof(char)*(strlen(l->name)+1));
 	t = (char *) exalloc(sizeof(char)*(strlen(s)+1));
@@ -901,6 +902,7 @@ Linkage_info analyze_fat_linkage(Sentence sent, Parse_Options opts, int analyze_
 	actx->structure_violation = FALSE;
 	d_root = build_DIS_CON_tree(actx, pi); /* may set structure_violation to TRUE */
 
+	memset(&li, 0, sizeof(li));
 	li.N_violations = 0;
 	li.improper_fat_linkage = actx->structure_violation;
 	li.inconsistent_domains = FALSE;
@@ -922,6 +924,10 @@ Linkage_info analyze_fat_linkage(Sentence sent, Parse_Options opts, int analyze_
 		free_sublinkage(sublinkage);
 		free_digraph(actx, pi);
 		free_DIS_tree(d_root);
+		for (i = 0; i < pi->N_links; i++)
+		{
+			pi->link_array[i].name = "";
+		}
 		return li;
 	}
 
