@@ -22,7 +22,7 @@
 
 /***************** utility routines (not exported) ***********************/
 
-static int string_in_list(const char * s, char * a[])
+static int string_in_list(const char * s, const char * a[])
 {
 	/* returns FALSE if the string s does not match anything in
 		 the array.	The array elements are post-processing symbols */
@@ -147,6 +147,7 @@ void post_process_free_data(PP_data * ppd)
 	ppd->links_to_ignore = NULL;
 }
 
+#ifdef THIS_FUNCTION_IS_NOT_CURRENTLY_USED
 static void connectivity_dfs(Postprocessor *pp, Sublinkage *sublinkage,
                              int w, pp_linkset *ls)
 {
@@ -159,6 +160,7 @@ static void connectivity_dfs(Postprocessor *pp, Sublinkage *sublinkage,
 			connectivity_dfs(pp, sublinkage, lol->word, ls);
 	}
 }
+#endif /* THIS_FUNCTION_IS_NOT_CURRENTLY_USED */
 
 static void mark_reachable_words(Postprocessor *pp, int w)
 {
@@ -269,7 +271,7 @@ static int apply_rules(Postprocessor *pp,
 							 int (applyfn) (Postprocessor *,Sublinkage *,pp_rule *),
 							 Sublinkage *sublinkage,
 							 pp_rule *rule_array,	
-							 char **msg)
+							 const char **msg)
 {
 	int i;
 	for (i=0; (*msg=rule_array[i].msg)!=NULL; i++)
@@ -283,7 +285,7 @@ apply_relevant_rules(Postprocessor *pp,
 						 Sublinkage *sublinkage,
 						 pp_rule *rule_array,	
 						 int *relevant_rules,
-						 char **msg)
+						 const char **msg)
 {
 	int i, idx;
 
@@ -746,7 +748,7 @@ static void build_domain_forest(Postprocessor *pp, Sublinkage *sublinkage)
 }
 
 static int
-internal_process(Postprocessor *pp,Sublinkage *sublinkage,char **msg)
+internal_process(Postprocessor *pp, Sublinkage *sublinkage, const char **msg)
 {
 	int i;
 	/* quick test: try applying just the relevant global rules */
@@ -845,7 +847,7 @@ static void prune_irrelevant_rules(Postprocessor *pp)
  * read rules from path and initialize the appropriate fields in
  * a postprocessor structure, a pointer to which is returned.
  */
-Postprocessor * post_process_open(char *path)
+Postprocessor * post_process_open(const char *path)
 {
 	Postprocessor *pp;
 	if (path==NULL) return NULL;
@@ -910,7 +912,7 @@ void post_process_close_sentence(Postprocessor *pp)
 void post_process_scan_linkage(Postprocessor *pp, Parse_Options opts,
 									 Sentence sent, Sublinkage *sublinkage)
 {
-	char *p;
+	const char *p;
 	int i;
 	if (pp == NULL) return;
 	if (sent->length < opts->twopass_length) return;
@@ -932,7 +934,7 @@ void post_process_scan_linkage(Postprocessor *pp, Parse_Options opts,
 PP_node *post_process(Postprocessor *pp, Parse_Options opts,
 							Sentence sent, Sublinkage *sublinkage, int cleanup)
 {
-	char *msg;
+	const char *msg;
 
 	if (pp==NULL) return NULL;
 
